@@ -39,26 +39,34 @@ def chromedriver():
 
 
 @chromedriver.command()
+@click.option('-s', '--skip-symlink', is_flag=True)
 @click.argument('target_dir', type=click.Path(path_type=Path), required=False)
-def download(target_dir):
+def download(skip_symlink, target_dir):
     """
-    Downloads the latest chromedriver for your Chrome Browser.
-    Naming convention: chromedriver-${VERSION}.
+    Downloads the latest chromedriver matching your Chrome browser version
+    and creates a symlink to it.
+
     Example:
 
         hukudo chromedriver download /tmp/
 
-    Results in `/tmp/chromedriver-
+    Results in `/tmp/chromedriver` pointing to `/tmp/chromedriver-101.0.4951.41`.
     """
     if target_dir is None:
         target_dir = Path()
     if not target_dir.is_dir():
         raise ClickException(f'not a directory: {target_dir}')
+
     try:
-        hukudo.chromedriver.download_latest(target_dir)
+        _, path = hukudo.chromedriver.download_latest(target_dir)
     except FileExistsError as e:
         raise ClickException(f'file exists: {e}')
 
+    if not skip_symlink:
+        link = target_dir / 'chromedriver'
+        link.unlink(missing_ok=True)
+        link.symlink_to(path)
+
 
 def main():
     root()
